@@ -1,8 +1,12 @@
 import base64
 import logging
+import os
+import warnings
 from binascii import Error as BinAsciiError
 from typing import Optional, Union
 
+from aws_lambda_powertools.shared import constants
+
 logger = logging.getLogger(__name__)
 
 
@@ -16,9 +20,9 @@ def strtobool(value: str) -> bool:
     > note:: Copied from distutils.util.
     """
     value = value.lower()
-    if value in ("y", "yes", "t", "true", "on", "1"):
+    if value in ("1", "y", "yes", "t", "true", "on"):
         return True
-    if value in ("n", "no", "f", "false", "off", "0"):
+    if value in ("0", "n", "no", "f", "false", "off"):
         return False
     raise ValueError(f"invalid truth value {value!r}")
 
@@ -67,7 +71,7 @@ def resolve_env_var_choice(
 
 def base64_decode(value: str) -> bytes:
     try:
-        logger.debug("Decoding base64 Kafka record item before parsing")
+        logger.debug("Decoding base64 record item before parsing")
         return base64.b64decode(value)
     except (BinAsciiError, TypeError):
         raise ValueError("base64 decode failed")
@@ -78,3 +82,21 @@ def bytes_to_string(value: bytes) -> str:
         return value.decode("utf-8")
     except (BinAsciiError, TypeError):
         raise ValueError("base64 UTF-8 decode failed")
+
+
+def powertools_dev_is_set() -> bool:
+    is_on = strtobool(os.getenv(constants.POWERTOOLS_DEV_ENV, "0"))
+    if is_on:
+        warnings.warn("POWERTOOLS_DEV environment variable is enabled. Increasing verbosity across utilities.")
+        return True
+
+    return False
+
+
+def powertools_debug_is_set() -> bool:
+    is_on = strtobool(os.getenv(constants.POWERTOOLS_DEBUG_ENV, "0"))
+    if is_on:
+        warnings.warn("POWERTOOLS_DEBUG environment variable is enabled. Setting logging level to DEBUG.")
+        return True
+
+    return False
