@@ -13,7 +13,10 @@ from aws_lambda_powertools.utilities.batch.base import (
     batch_processor,
 )
 from aws_lambda_powertools.utilities.batch.exceptions import ExceptionInfo
-from aws_lambda_powertools.utilities.batch.sqs import PartialSQSProcessor, sqs_batch_processor
+from aws_lambda_powertools.utilities.batch.sqs import (
+    PartialSQSProcessor,
+    sqs_batch_processor,
+)
 
 __all__ = (
     "BatchProcessor",
