@@ -123,23 +123,26 @@ class RequestContextV2AuthorizerIam(DictWrapper):
         """The principal identifier of the caller making the request."""
         return self.get("callerId")
 
+    def _cognito_identity(self) -> Dict:
+        return self.get("cognitoIdentity", {}) or {}  # not available in FunctionURL
+
     @property
     def cognito_amr(self) -> Optional[List[str]]:
         """This represents how the user was authenticated.
         AMR stands for  Authentication Methods References as per the openid spec"""
-        return self["cognitoIdentity"].get("amr")
+        return self._cognito_identity().get("amr")
 
     @property
     def cognito_identity_id(self) -> Optional[str]:
         """The Amazon Cognito identity ID of the caller making the request.
         Available only if the request was signed with Amazon Cognito credentials."""
-        return self["cognitoIdentity"].get("identityId")
+        return self._cognito_identity().get("identityId")
 
     @property
     def cognito_identity_pool_id(self) -> Optional[str]:
         """The Amazon Cognito identity pool ID of the caller making the request.
         Available only if the request was signed with Amazon Cognito credentials."""
-        return self["cognitoIdentity"].get("identityPoolId")
+        return self._cognito_identity().get("identityPoolId")
 
     @property
     def principal_org_id(self) -> Optional[str]:
@@ -159,12 +162,14 @@ class RequestContextV2AuthorizerIam(DictWrapper):
 
 class RequestContextV2Authorizer(DictWrapper):
     @property
-    def jwt_claim(self) -> Dict[str, Any]:
-        return self["jwt"]["claims"]
+    def jwt_claim(self) -> Optional[Dict[str, Any]]:
+        jwt = self.get("jwt") or {}  # not available in FunctionURL
+        return jwt.get("claims")
 
     @property
-    def jwt_scopes(self) -> List[str]:
-        return self["jwt"]["scopes"]
+    def jwt_scopes(self) -> Optional[List[str]]:
+        jwt = self.get("jwt") or {}  # not available in FunctionURL
+        return jwt.get("scopes")
 
     @property
     def get_lambda(self) -> Optional[Dict[str, Any]]:
