@@ -1,4 +1,6 @@
-from aws_lambda_powertools.utilities.data_classes.api_gateway_proxy_event import APIGatewayProxyEventV2
+from aws_lambda_powertools.utilities.data_classes.api_gateway_proxy_event import (
+    APIGatewayProxyEventV2,
+)
 
 
 class LambdaFunctionUrlEvent(APIGatewayProxyEventV2):
